@@ -89,7 +89,7 @@ def get_factors(gh_actions_config, versions):
         if version in gh_actions_config["python"]:
             verbosity2("got factors for Python version: {}".format(version))
             factors.append(gh_actions_config["python"][version])
-            break  # Shoudn't check remaining versions
+            break  # Shouldn't check remaining versions
     for env, env_config in gh_actions_config.get("env", {}).items():
         if env in os.environ:
             env_value = os.environ[env]
@@ -120,6 +120,7 @@ def get_python_version_keys():
     - CPython 3.8.z => [3.8, 3]
     - PyPy 2.7 (v7.3.z) => [pypy-2.7, pypy-2, pypy2]
     - PyPy 3.6 (v7.3.z) => [pypy-3.6, pypy-3, pypy3]
+    - Pyston based on Python CPython 3.8.8 (v2.2) => [pyston-3.8, pyston-3]
 
     Support of "pypy2" and "pypy3" is for backward compatibility with
     tox-gh-actions v2.2.0 and before.
@@ -132,6 +133,11 @@ def get_python_version_keys():
             "pypy-" + major_version,
             "pypy" + major_version,
         ]
+    elif hasattr(sys, "pyston_version_info"):  # Pyston
+        return [
+            "pyston-" + major_minor_version,
+            "pyston-" + major_version,
+        ]
     else:
         # Assume this is running on CPython
         return [major_minor_version, major_version]
